@@ -121,7 +121,9 @@ static int init_modules(int argc, char *argv[])
 	if ((ret=cmdhlp()))
 		return ret;
 
+#ifndef _WIN32
 	if (!geteuid())
+	{
 		if (getuid())
 		{
 			fprintf(stderr, "Changing user to non-root\n");
@@ -131,7 +133,9 @@ static int init_modules(int argc, char *argv[])
 				return errGen;
 			}
 		}
+	}
 	if (!getegid())
+	{
 		if (getgid())
 		{
 			fprintf(stderr, "Changing group to non-root\n");
@@ -141,6 +145,8 @@ static int init_modules(int argc, char *argv[])
 				return errGen;
 			}
 		}
+	}
+#endif
 
 	framelock_init ();
 
@@ -975,9 +981,32 @@ static int init_modules(int argc, char *argv[])
 			cfSetProfileComment ("adplug", "emulator", "; Possible values are ken, nuked, satoh and woody.");
 		}
 
-		if (epoch < 20230403)
+		if (epoch < 20230607)
 		{
-			cfSetProfileInt("version", "epoch", 20230403, 10);
+			fprintf(stderr, "ocp.ini update (0.2.106), added playgme plugin\n");
+			cfSetProfileInt ("fscolors", "AY2", 13, 10);
+			cfSetProfileInt ("fscolors", "GBS", 13, 10);
+			cfSetProfileInt ("fscolors", "GYM", 13, 10);
+			cfSetProfileInt ("fscolors", "HES", 13, 10);
+			cfSetProfileInt ("fscolors", "KSS", 13, 10);
+			cfSetProfileInt ("fscolors", "NSF", 13, 10);
+			cfSetProfileInt ("fscolors", "NSFe", 13, 10);
+			cfSetProfileInt ("fscolors", "SAP", 13, 10);
+			cfSetProfileInt ("fscolors", "SPC", 13, 10);
+			cfSetProfileInt ("fscolors", "VGM", 13, 10);
+		}
+
+		if (epoch < 20230630)
+		{
+			fprintf(stderr, "ocp.ini update (0.2.106), added [adplug] retrowave support\n");
+			cfSetProfileComment ("adplug", "emulator", "; Possible values are ken, nuked, satoh, woody and retrowave.");
+			cfSetProfileString  ("adplug", "retrowave", "auto");
+			cfSetProfileComment ("adplug", "retrowave", "; Device to use, e.g. /dev/ttyACM0 /dev/cuaU0 /dev/dtyU0 /dev/cu.usbmodem0000001 COM1");
+		}
+
+		if (epoch < 20230630)
+		{
+			cfSetProfileInt("version", "epoch", 20230630, 10);
 			cfStoreConfig();
 			if (isatty(2))
 			{
@@ -988,13 +1017,13 @@ static int init_modules(int argc, char *argv[])
 			sleep(5);
 		}
 	}
-	if (cfGetProfileInt("version", "epoch", 0, 10) != 20230403)
+	if (cfGetProfileInt("version", "epoch", 0, 10) != 20230630)
 	{
 		if (isatty(2))
 		{
-			fprintf(stderr,"\n\033[1m\033[31mWARNING, ocp.ini [version] epoch != 20230403\033[0m\n\n");
+			fprintf(stderr,"\n\033[1m\033[31mWARNING, ocp.ini [version] epoch != 20230630\033[0m\n\n");
 		} else {
-			fprintf(stderr,"\nWARNING, ocp.ini [version] epoch != 20230403\n\n");
+			fprintf(stderr,"\nWARNING, ocp.ini [version] epoch != 20230630\n\n");
 		}
 		sleep(5);
 	}
@@ -1005,9 +1034,9 @@ static int init_modules(int argc, char *argv[])
 	lnkLink(cfGetProfileString2(cfConfigSec, "defaultconfig", "prelink", ""));
 	lnkLink(cfGetProfileString("general", "prelink", ""));
 
-	if (lnkLinkDir(cfProgramDirAutoload)<0)
+	if (lnkLinkDir(cfProgramPathAutoload)<0)
 	{
-		fprintf(stderr, "could not autoload directory: %s\n", cfProgramDirAutoload);
+		fprintf(stderr, "could not autoload directory: %s\n", cfProgramPathAutoload);
 		return -1;
 	}
 
@@ -1056,9 +1085,10 @@ int failcheck(signed int source, signed int filter)
 }
 #endif
 
-static int _bootup(int argc, char *argv[], const char *ConfigHomeDir, const char *ConfigDataDir, const char *DataDir, const char *ProgramDir)
+static int _bootup(int argc, char *argv[], const char *HomePath, const char *ConfigHomePath, const char *ConfigDataPath, const char *DataPath, const char *ProgramPath)
 {
 	int result;
+#ifndef _WIN32
 	if (isatty(2))
 	{
 		fprintf(stderr, "\033[33m\033[1mOpen Cubic Player for Unix \033[32mv" VERSION "\033[33m, compiled on %s, %s\n", compiledate, compiletime);
@@ -1085,22 +1115,31 @@ static int _bootup(int argc, char *argv[], const char *ConfigHomeDir, const char
 	}
 	fprintf(stderr, "pass\n");
 #endif
+#else
+	fprintf(stderr, "Open Cubic Player for mingw v" VERSION ", compiled on %s, %s\n", compiledate, compiletime);
+	fprintf(stderr, "Ported to Unix and mingw by Stian Skjelstad\n");
+#endif
 
-	cfConfigHomeDir = (char *)ConfigHomeDir;
-	cfDataHomeDir = (char*)ConfigDataDir;
-	cfDataDir = strdup (DataDir);
-	cfProgramDir = (char *)ProgramDir;
-	cfProgramDirAutoload = malloc (strlen (cfProgramDir) + 9 + 1);
-	sprintf(cfProgramDirAutoload, "%sautoload/", cfProgramDir);
+	cfHomePath = (char *)HomePath;
+	cfConfigHomePath = (char *)ConfigHomePath;
+	cfDataHomePath = (char*)ConfigDataPath;
+	cfDataPath = strdup (DataPath);
+	cfProgramPath = (char *)ProgramPath;
+	cfProgramPathAutoload = malloc (strlen (cfProgramPath) + 9 + 1);
+#ifdef _WIN32
+	sprintf(cfProgramPathAutoload, "%sautoload\\", cfProgramPath);
+#else
+	sprintf(cfProgramPathAutoload, "%sautoload/", cfProgramPath);
+#endif
 
 	if (cfGetConfig(argc, argv))
 	{
-		cfConfigHomeDir = 0;
-		cfDataHomeDir = 0;
-		free (cfDataDir); cfDataDir = 0;
-		cfProgramDir = 0;
-		free (cfTempDir); cfTempDir = 0;
-		free (cfProgramDirAutoload); cfProgramDirAutoload = 0;
+		cfConfigHomePath = 0;
+		cfDataHomePath = 0;
+		free (cfDataPath); cfDataPath = 0;
+		free (cfTempPath); cfTempPath = 0;
+		cfProgramPath = 0;
+		free (cfProgramPathAutoload); cfProgramPathAutoload = 0;
 		return -1;
 	}
 
@@ -1113,12 +1152,12 @@ static int _bootup(int argc, char *argv[], const char *ConfigHomeDir, const char
 
 	cfCloseConfig();
 
-	cfConfigHomeDir = 0;
-	cfDataHomeDir = 0;
-	free (cfDataDir); cfDataDir = 0;
-	cfProgramDir = 0;
-	free (cfTempDir); cfTempDir = 0;
-	free (cfProgramDirAutoload); cfProgramDirAutoload = 0;
+	cfConfigHomePath = 0;
+	cfDataHomePath = 0;
+	free (cfDataPath); cfDataPath = 0;
+	free (cfTempPath); cfTempPath = 0;
+	cfProgramPath = 0;
+	free (cfProgramPathAutoload); cfProgramPathAutoload = 0;
 
 
 	return 0;
