@@ -1,6 +1,6 @@
 /* OpenCP Module Player
  * copyright (c) 1994-'10 Niklas Beisert <nbeisert@physik.tu-muenchen.de>
- * copyright (c) 2004-'20 Stian Skjelstad <stian.skjelstad@gmail.com>
+ * copyright (c) 2004-'23 Stian Skjelstad <stian.skjelstad@gmail.com>
  *
  * ITPlayer - player for Impulse Tracker 2.xx modules
  *
@@ -82,6 +82,7 @@
 #include "cpiface/cpiface.h"
 #include "dev/mcp.h"
 #include "itplay.h"
+#include "stuff/err.h"
 #include "stuff/imsrtns.h"
 
 
@@ -119,23 +120,23 @@ static int8_t sintab[256] =
 };
 
 
-static void playtick(struct itplayer *this);
+static void playtick (struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this);
 static int range64(int v);
 static int range128(int v);
 static void dovibrato(struct itplayer *this, struct it_logchan *c);
 static void putque(struct itplayer *this, int type, int val1, int val2);
-static void readque(struct itplayer *this);
+static void readque (struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this);
 static void dotremolo(struct itplayer *this, struct it_logchan *c);
-static void dodelay(struct itplayer *this, struct it_logchan *c);
+static void dodelay(struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this, struct it_logchan *c);
 static void dopanbrello(struct itplayer *this, struct it_logchan *c);
 
 
-static void playtickstatic(void)
+static void playtickstatic (struct cpifaceSessionAPI_t *cpifaceSession)
 {
-	playtick(staticthis);
+	playtick (cpifaceSession, staticthis);
 }
 
-static void playnote(struct itplayer *this, struct it_logchan *c, const uint8_t *cmd)
+static void playnote(struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this, struct it_logchan *c, const uint8_t *cmd)
 {
 	int instchange=0;
 	/* int triginst=0;  unused */
@@ -378,7 +379,7 @@ static void playnote(struct itplayer *this, struct it_logchan *c, const uint8_t
 
 	frq=p->noteoffset-256*(c->lastnote-cmdNNote);
 	if (!this->linear)
-		frq=mcpGetFreq6848(frq);
+		frq=cpifaceSession->mcpAPI->GetFreq6848(frq);
 	c->dpitch=frq;
 	if (!porta)
 		c->fpitch=c->pitch=c->dpitch;
@@ -590,7 +591,7 @@ static void parsemidicmd(struct it_logchan *c, char *cmd, int z)
 	}
 }
 
-static void playcmd(struct itplayer *this, struct it_logchan *c, int cmd, int data)
+static void playcmd(struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this, struct it_logchan *c, int cmd, int data)
 {
 	int i;
 	c->command=cmd;
@@ -922,7 +923,7 @@ static void playcmd(struct itplayer *this, struct it_logchan *c, int cmd, int da
 					c->fx=ifxDelay;
 					if (!c->specialdata)
 						c->specialdata++; /* SD0 should do the same as SD1 */
-					dodelay(this, c);
+					dodelay(cpifaceSession, this, c);
 					break;
 				case cmdSPatDelayRow:
 					if (!this->patdelayrow) /* only use the first command, per row */
@@ -1075,12 +1076,12 @@ static void doportanote(struct itplayer *this, struct it_logchan *c, int v) /* i
 		c->dpitch=0;
 }
 
-static void dodelay(struct itplayer *this, struct it_logchan *c)
+static void dodelay(struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this, struct it_logchan *c)
 {
 	if (this->curtick==c->specialdata)
 	{
 		if (c->delayed[0]||c->delayed[1])
-			playnote(this, c, c->delayed);
+			playnote(cpifaceSession, this, c, c->delayed);
 		if (c->delayed[2])
 			playvcmd(this, c, c->delayed[2]);
 	} else if (((this->curtick+1)==(this->speed+this->patdelaytick))&&(!this->patdelayrow))
@@ -1108,7 +1109,7 @@ static const uint16_t arpnotetab[] =
 	16384, 15464, 14596, 13777
 };
 
-static void processfx(struct itplayer *this, struct it_logchan *c)
+static void processfx(struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this, struct it_logchan *c)
 {
 	switch (c->command)
 	{
@@ -1214,7 +1215,7 @@ static void processfx(struct itplayer *this, struct it_logchan *c)
 						c->pch->notecut=1;
 					break;
 				case cmdSNoteDelay:
-					dodelay(this, c);
+					dodelay(cpifaceSession, this, c);
 					break;
 				case cmdSPatDelayRow:
 					break;
@@ -1428,42 +1429,42 @@ static void processchan(struct itplayer *this, struct it_physchan *p)
 
 }
 
-static void putchandata(struct itplayer *this, struct it_physchan *p)
+static void putchandata (struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this, struct it_physchan *p)
 {
 	if (p->newsamp!=-1)
 	{
-		mcpSet(p->no, mcpCReset, 0);
-		mcpSet(p->no, mcpCInstrument, p->newsamp);
+		cpifaceSession->mcpSet (cpifaceSession, p->no, mcpCReset, 0);
+		cpifaceSession->mcpSet (cpifaceSession, p->no, mcpCInstrument, p->newsamp);
 		p->newsamp=-1;
 	}
 	if (p->newpos!=-1)
 	{
-		mcpSet(p->no, mcpCPosition, p->newpos);
-		mcpSet(p->no, mcpCLoop, 1);
-		mcpSet(p->no, mcpCDirect, 0);
-		mcpSet(p->no, mcpCStatus, 1);
+		cpifaceSession->mcpSet (cpifaceSession, p->no, mcpCPosition, p->newpos);
+		cpifaceSession->mcpSet (cpifaceSession, p->no, mcpCLoop, 1);
+		cpifaceSession->mcpSet (cpifaceSession, p->no, mcpCDirect, 0);
+		cpifaceSession->mcpSet (cpifaceSession, p->no, mcpCStatus, 1);
 		p->newpos=-1;
 		p->dead=0;
 	}
 	if (p->noteoff&&!p->looptype)
 	{
-		mcpSet(p->no, mcpCLoop, 2);
+		cpifaceSession->mcpSet (cpifaceSession, p->no, mcpCLoop, 2);
 		p->looptype=1;
 	}
 	if (this->linear)
-		mcpSet(p->no, mcpCPitch, p->fpitch);
+		cpifaceSession->mcpSet (cpifaceSession, p->no, mcpCPitch, p->fpitch);
 	else
-		mcpSet(p->no, mcpCPitch6848, -p->fpitch);
+		cpifaceSession->mcpSet (cpifaceSession, p->no, mcpCPitch6848, -p->fpitch);
 
-	mcpSet(p->no, mcpCVolume, p->fvol);
-	mcpSet(p->no, mcpCPanning, p->fpan);
-	mcpSet(p->no, mcpCSurround, p->srnd);
-	mcpSet(p->no, mcpCMute, this->channels[p->lch].mute);
-	mcpSet(p->no, mcpCFilterFreq, p->fcutoff);
-	mcpSet(p->no, mcpCFilterRez, p->reso);
+	cpifaceSession->mcpSet (cpifaceSession, p->no, mcpCVolume, p->fvol);
+	cpifaceSession->mcpSet (cpifaceSession, p->no, mcpCPanning, p->fpan);
+	cpifaceSession->mcpSet (cpifaceSession, p->no, mcpCSurround, p->srnd);
+	cpifaceSession->mcpSet (cpifaceSession, p->no, mcpCMute, this->channels[p->lch].mute);
+	cpifaceSession->mcpSet (cpifaceSession, p->no, mcpCFilterFreq, p->fcutoff);
+	cpifaceSession->mcpSet (cpifaceSession, p->no, mcpCFilterRez, p->reso);
 }
 
-void __attribute__ ((visibility ("internal"))) mutechan(struct itplayer *this, int c, int m)
+OCP_INTERNAL void mutechan (struct itplayer *this, int c, int m)
 {
 	if ((c>=0)||(c<this->nchan))
 		this->channels[c].mute=m;
@@ -1531,14 +1532,14 @@ static void allocatechan(struct itplayer *this, struct it_logchan *c)
 
 }
 
-static void getproctime(struct itplayer *this)
+static void getproctime (struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this)
 {
-	this->proctime=mcpGet(-1, mcpGCmdTimer);
+	this->proctime = cpifaceSession->mcpGet (cpifaceSession, -1, mcpGCmdTimer);
 }
 
-static void putglobdata(struct itplayer *this)
+static void putglobdata (struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this)
 {
-	mcpSet(-1, mcpGSpeed, 256*2*this->tempo/5);
+	cpifaceSession->mcpSet (cpifaceSession, -1, mcpGSpeed, 256*2*this->tempo/5);
 }
 
 static void putque(struct itplayer *this, int type, int val1, int val2)
@@ -1552,15 +1553,15 @@ static void putque(struct itplayer *this, int type, int val1, int val2)
 	this->quewpos=(this->quewpos+1)%this->quelen;
 }
 
-static int gettime(void)
+static int gettime (struct cpifaceSessionAPI_t *cpifaceSession)
 {
-	return mcpGet(-1, mcpGTimer);
+	return cpifaceSession->mcpGet (cpifaceSession, -1, mcpGTimer);
 }
 
-static void readque(struct itplayer *this)
+static void readque (struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this)
 {
 	int i;
-	int time=gettime();
+	int time = gettime (cpifaceSession);
 	while (1)
 	{
 		int t, val1, val2;
@@ -1623,9 +1624,9 @@ static void readque(struct itplayer *this)
 	}
 }
 
-static void checkchan(struct itplayer *this, struct it_physchan *p)
+static void checkchan (struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this, struct it_physchan *p)
 {
-	if (!mcpGet(p->no, mcpCStatus))
+	if (!cpifaceSession->mcpGet (cpifaceSession, p->no, mcpCStatus))
 		p->dead=1;
 	if (p->dead&&(this->channels[p->lch].pch!=p))
 		p->notecut=1;
@@ -1634,27 +1635,30 @@ static void checkchan(struct itplayer *this, struct it_physchan *p)
 		if (this->channels[p->lch].pch==p)
 			this->channels[p->lch].pch=0;
 		p->lch=-1;
-		mcpSet(p->no, mcpCReset, 0);
+		cpifaceSession->mcpSet (cpifaceSession, p->no, mcpCReset, 0);
 		return;
 	}
 }
 
-static void playtick(struct itplayer *this)
+static void playtick (struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this)
 {
 	int i;
 
+	if (this->looped&&this->noloop)
+	{
+		cpifaceSession->mcpSet (cpifaceSession, -1, mcpMasterPause, 1);
+		return;
+	}
+
 	if (!this->npchan)
 		return;
 
-	getproctime(this);
-	readque(this);
+	getproctime (cpifaceSession, this);
+	readque (cpifaceSession, this);
 
 	for (i=0; i<this->nchan; i++)
 		inittick(&this->channels[i]);
 
-	if (this->looped&&this->noloop)
-		return;
-
 	this->curtick++;
 	if ((this->curtick==(this->speed+this->patdelaytick))&&this->patdelayrow)
 	{
@@ -1708,6 +1712,10 @@ static void playtick(struct itplayer *this)
 					c->tremoroffcounter=0;
 				}
 			}
+			if (this->gotoord < this->curord && !this->manualgoto)
+			{
+				this->looped=1;
+			}
 			while (this->orders[this->gotoord]==0xFFFF)
 				this->gotoord++;
 			if (this->gotoord==this->endord)
@@ -1759,11 +1767,11 @@ static void playtick(struct itplayer *this)
 				delay=1;
 			} else {
 				if (this->patptr[0]||this->patptr[1])
-					playnote(this, c, this->patptr);
+					playnote(cpifaceSession, this, c, this->patptr);
 				delay=0;
 			}
 			if (this->patptr[3])
-				playcmd(this, c, this->patptr[3], this->patptr[4]); /* we need notedata to know if Portamento should do anything */
+				playcmd(cpifaceSession, this, c, this->patptr[3], this->patptr[4]); /* we need notedata to know if Portamento should do anything */
 			if (!delay)
 				if (this->patptr[2])
 					playvcmd(this, c, this->patptr[2]);
@@ -1774,7 +1782,7 @@ static void playtick(struct itplayer *this)
 			this->patdelayrow--;
 	} else
 		for (i=0; i<this->nchan; i++)
-			processfx(this, &this->channels[i]);
+			processfx(cpifaceSession, this, &this->channels[i]);
 
 	this->manualgoto=0;
 	this->gvolslide=0;
@@ -1785,7 +1793,7 @@ static void playtick(struct itplayer *this)
 		updatechan(&this->channels[i]);
 	for (i=0; i<this->npchan; i++)
 		if (this->pchannels[i].lch!=-1)
-			checkchan(this, &this->pchannels[i]);
+			checkchan (cpifaceSession, this, &this->pchannels[i]);
 	for (i=0; i<this->npchan; i++)
 		if (this->pchannels[i].lch!=-1)
 			processchan(this, &this->pchannels[i]);
@@ -1797,22 +1805,27 @@ static void playtick(struct itplayer *this)
 		}
 	for (i=0; i<this->npchan; i++)
 		if (this->pchannels[i].lch!=-1)
-			putchandata(this, &this->pchannels[i]);
+			putchandata (cpifaceSession, this, &this->pchannels[i]);
 
-	putglobdata(this);
+	putglobdata (cpifaceSession, this);
 	putque(this, quePos, -1, (this->curtick&0xFF)|(this->currow<<8)|(this->curord<<16));
 }
 
-int __attribute__ ((visibility ("internal"))) loadsamples(struct it_module *m)
+OCP_INTERNAL int loadsamples (struct cpifaceSessionAPI_t *cpifaceSession, struct it_module *m)
 {
-	return mcpLoadSamples(m->sampleinfos, m->nsampi);
+	return cpifaceSession->mcpDevAPI->LoadSamples (cpifaceSession, m->sampleinfos, m->nsampi);
 }
 
-int __attribute__ ((visibility ("internal"))) play(struct itplayer *this, const struct it_module *m, int ch, struct ocpfilehandle_t *file)
+OCP_INTERNAL int itplay (struct itplayer *this, const struct it_module *m, int ch, struct ocpfilehandle_t *file, struct cpifaceSessionAPI_t *cpifaceSession)
 {
 	int i;
-	staticthis=this;
 
+	if (!cpifaceSession->mcpDevAPI)
+	{
+		return errPlay;
+	}
+
+	staticthis=this;
 	this->randseed=1;
 	this->patdelayrow=0;
 	this->patdelaytick=0;
@@ -1855,7 +1868,9 @@ int __attribute__ ((visibility ("internal"))) play(struct itplayer *this, const
 		this->curord++;
 
 	if (this->curord==this->nord)
-		return 0;
+	{
+		return errFormStruc;
+	}
 
 	this->channels=malloc(sizeof(struct it_logchan)*this->nchan);
 	this->pchannels=malloc(sizeof(struct it_physchan)*ch);
@@ -1878,7 +1893,7 @@ int __attribute__ ((visibility ("internal"))) play(struct itplayer *this, const
 			free(this->que);
 			this->que=NULL;
 		}
-		return 0;
+		return errFormStruc;
 	}
 	this->querpos=this->quewpos=0;
 	memset(this->channels, 0, sizeof(*this->channels)*this->nchan);
@@ -1900,19 +1915,21 @@ int __attribute__ ((visibility ("internal"))) play(struct itplayer *this, const
 		c->tremoroffcounter=0;
 	}
 
-	if (!mcpOpenPlayer(ch, playtickstatic, file))
-		return 0;
+	if (!cpifaceSession->mcpDevAPI->OpenPlayer(ch, playtickstatic, file, cpifaceSession))
+	{
+		return errPlay;
+	}
 
-	mcpNormalize (mcpNormalizeDefaultPlayW);
+	cpifaceSession->Normalize (cpifaceSession, mcpNormalizeDefaultPlayW);
 
-	this->npchan=mcpNChan;
+	this->npchan = cpifaceSession->PhysicalChannelCount;
 
-	return 1;
+	return errOk;
 }
 
-void __attribute__ ((visibility ("internal"))) stop(struct itplayer *this)
+OCP_INTERNAL void itstop (struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this)
 {
-	mcpClosePlayer();
+	cpifaceSession->mcpDevAPI->ClosePlayer (cpifaceSession);
 	if (this->channels)
 	{
 		free(this->channels);
@@ -1930,20 +1947,20 @@ void __attribute__ ((visibility ("internal"))) stop(struct itplayer *this)
 	}
 }
 
-int __attribute__ ((visibility ("internal"))) getpos(struct itplayer *this)
+OCP_INTERNAL int getpos (struct itplayer *this)
 {
 	if (this->manualgoto)
 		return (this->gotorow<<8)|(this->gotoord<<16);
 	return (this->curtick&0xFF)|(this->currow<<8)|(this->curord<<16);
 }
 
-int __attribute__ ((visibility ("internal"))) getrealpos(struct itplayer *this)
+OCP_INTERNAL int getrealpos (struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this)
 {
-	readque(this);
+	readque (cpifaceSession, this);
 	return this->realpos;
 }
 
-int __attribute__ ((visibility ("internal"))) getchansample(struct itplayer *this, int ch, int16_t *buf, int len, uint32_t rate, int opt)
+OCP_INTERNAL int getchansample (struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this, int ch, int16_t *buf, int len, uint32_t rate, int opt)
 {
 	int i,n;
 	unsigned int chn[64];
@@ -1951,11 +1968,11 @@ int __attribute__ ((visibility ("internal"))) getchansample(struct itplayer *thi
 	for (i=0; i<this->npchan; i++)
 		if (this->pchannels[i].lch==ch)
 			chn[n++]=i;
-	mcpMixChanSamples(chn, n, buf, len, rate, opt);
+	cpifaceSession->mcpMixChanSamples (cpifaceSession, chn, n, buf, len, rate, opt);
 	return 1;
 }
 
-void __attribute__ ((visibility ("internal"))) itplayer_getrealvol(struct itplayer *this, int ch, int *l, int *r)
+OCP_INTERNAL void itplayer_getrealvol (struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this, int ch, int *l, int *r)
 {
 	int i, voll, volr;
 
@@ -1964,13 +1981,13 @@ void __attribute__ ((visibility ("internal"))) itplayer_getrealvol(struct itplay
 	for (i=0; i<this->npchan; i++)
 		if (this->pchannels[i].lch==ch)
 		{
-			mcpGetRealVolume(i, &voll, &volr);
+			cpifaceSession->mcpGetRealVolume (i, &voll, &volr);
 			(*l)+=voll;
 			(*r)+=volr;
 		}
 }
 
-void __attribute__ ((visibility ("internal"))) setpos(struct itplayer *this, int ord, int row)
+OCP_INTERNAL void setpos (struct itplayer *this, int ord, int row)
 {
 	int i;
 	if (this->curord!=ord)
@@ -1991,7 +2008,7 @@ void __attribute__ ((visibility ("internal"))) setpos(struct itplayer *this, int
 	this->realpos=(this->gotorow<<8)|(this->gotoord<<16);
 }
 
-int __attribute__ ((visibility ("internal"))) getdotsdata(struct itplayer *this, int ch, int pch, int *smp, int *note, int *voll, int *volr, int *sus)
+OCP_INTERNAL int getdotsdata (struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this, int ch, int pch, int *smp, int *note, int *voll, int *volr, int *sus)
 {
 	struct it_physchan *p;
 	for (; pch<this->npchan; pch++)
@@ -2006,50 +2023,50 @@ int __attribute__ ((visibility ("internal"))) getdotsdata(struct itplayer *this,
 		*note=p->noteoffset+p->fpitch;
 	else
 		if (p->noteoffset+p->fpitch)
-			*note=p->noteoffset+mcpGetNote8363(6848*8363/p->fpitch);
+			*note=p->noteoffset+cpifaceSession->mcpAPI->GetNote8363(6848*8363/p->fpitch);
 		else
 			*note=0;
 
-	mcpGetRealVolume(p->no, voll, volr);
+	cpifaceSession->mcpGetRealVolume (p->no, voll, volr);
 	*sus=!(p->noteoff||p->notefade);
 	return pch+1;
 }
 
-void __attribute__ ((visibility ("internal"))) getglobinfo(struct itplayer *this, int *tmp, int *bp, int *gv, int *gs)
+OCP_INTERNAL void getglobinfo (struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this, int *tmp, int *bp, int *gv, int *gs)
 {
-	readque(this);
+	readque (cpifaceSession, this);
 	*tmp=this->realspeed;
 	*bp=this->realtempo;
 	*gv=this->realgvol;
 	*gs=this->gvolslide?(this->gvolslide>0?ifxGVSUp:ifxGVSDown):0;
 }
 
-int __attribute__ ((visibility ("internal"))) getsync(struct itplayer *this, int ch, int *time)
+OCP_INTERNAL int getsync (struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this, int ch, int *time)
 {
-	readque(this);
+	readque (cpifaceSession, this);
 	if ((ch<0)||(ch>=this->nchan))
 	{
-		*time=gettime()-this->realsynctime;
+		*time = gettime(cpifaceSession) - this->realsynctime;
 		return this->realsync;
 	} else {
-		*time=gettime()-this->channels[ch].realsynctime;
+		*time = gettime(cpifaceSession) - this->channels[ch].realsynctime;
 		return this->channels[ch].realsync;
 	}
 }
 /*
-int __attribute__ ((visibility ("internal"))) getticktime(struct itplayer *this)
+OCP_INTERNAL int getticktime (struct itplayer *this)
 {
 	readque(this);
 	return 65536*5/(2*this->realtempo);
 }
 
-int __attribute__ ((visibility ("internal"))) getrowtime(struct itplayer *this)
+OCP_INTERNAL int getrowtime (struct itplayer *this)
 {
 	readque(this);
 	return 65536*5*this->realspeed/(2*this->realtempo);
 }*/
 /*
-void __attribute__ ((visibility ("internal"))) setevpos(struct itplayer *this, int ch, int pos, int modtype, int mod)
+OCP_INTERNAL void setevpos (struct itplayer *this, int ch, int pos, int modtype, int mod)
 {
 	struct it_logchan *c;
 	if ((ch<0)||(ch>=this->nchan))
@@ -2064,7 +2081,7 @@ void __attribute__ ((visibility ("internal"))) setevpos(struct itplayer *this, i
 }
 */
 /*
-int __attribute__ ((visibility ("internal"))) getevpos(struct itplayer *this, int ch, int *time)
+OCP_INTERNAL int getevpos (struct itplayer *this, int ch, int *time)
 {
 	readque(this);
 	if ((ch<0)||(ch>=this->nchan))
@@ -2077,7 +2094,7 @@ int __attribute__ ((visibility ("internal"))) getevpos(struct itplayer *this, in
 }
 */
 /*
-int __attribute__ ((visibility ("internal"))) findevpos(struct itplayer *this, int pos, int *time)
+OCP_INTERNAL int findevpos (struct itplayer *this, int pos, int *time)
 {
 	int i;
 	readque(this);
@@ -2089,42 +2106,42 @@ int __attribute__ ((visibility ("internal"))) findevpos(struct itplayer *this, i
 }
 */
 
-void __attribute__ ((visibility ("internal"))) setloop(struct itplayer *this, int s)
+OCP_INTERNAL void setloop (struct itplayer *this, int s)
 {
 	this->noloop=!s;
 }
 
-int __attribute__ ((visibility ("internal"))) getloop(struct itplayer *this)
+OCP_INTERNAL int getloop (struct itplayer *this)
 {
 	return this->looped;
 }
 
-int __attribute__ ((visibility ("internal"))) chanactive(struct itplayer *this, int ch, int *lc)
+OCP_INTERNAL int chanactive (struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this, int ch, int *lc)
 {
 	struct it_physchan *p=&this->pchannels[ch];
 	*lc=p->lch;
 	if (!(*lc>-1)&&p->smp&&p->fvol)
 		return 0; /* force mcpGet to be checked last - stian */
-	return mcpGet(ch, mcpCStatus);
+	return cpifaceSession->mcpGet(cpifaceSession, ch, mcpCStatus);
 }
 
-int __attribute__ ((visibility ("internal"))) lchanactive(struct itplayer *this, int lc)
+OCP_INTERNAL int lchanactive (struct cpifaceSessionAPI_t *cpifaceSession, struct itplayer *this, int lc)
 {
 	struct it_physchan *p=this->channels[lc].pch;
 	if (!p)
 		return 0; /* avoid strange crashes on some archs - stian */
 	if (!(p->smp&&p->fvol))
 		return 0; /* force mcpGet to be checked last - stian */
-	return mcpGet(p->no, mcpCStatus);
+	return cpifaceSession->mcpGet (cpifaceSession, p->no, mcpCStatus);
 }
 
-int __attribute__ ((visibility ("internal"))) getchanins(struct itplayer *this, int ch)
+OCP_INTERNAL int getchanins (struct itplayer *this, int ch)
 {
 	struct it_physchan *p=&this->pchannels[ch];
 	return p->inst->handle+1;
 }
 
-int __attribute__ ((visibility ("internal"))) getchansamp(struct itplayer *this, int ch)
+OCP_INTERNAL int getchansamp (struct itplayer *this, int ch)
 {
 	struct it_physchan *p=&this->pchannels[ch];
 	if (!p->smp)
@@ -2133,7 +2150,7 @@ int __attribute__ ((visibility ("internal"))) getchansamp(struct itplayer *this,
 }
 
 
-void __attribute__ ((visibility ("internal"))) getchaninfo(struct itplayer *this, uint8_t ch, struct it_chaninfo *ci)
+OCP_INTERNAL void getchaninfo (struct itplayer *this, uint8_t ch, struct it_chaninfo *ci)
 {
 	const struct it_logchan *t=&this->channels[ch];
 	if (t->pch)
@@ -2157,7 +2174,7 @@ void __attribute__ ((visibility ("internal"))) getchaninfo(struct itplayer *this
 		memset(ci, 0, sizeof(*ci));
 }
 
-int __attribute__ ((visibility ("internal"))) getchanalloc(struct itplayer *this, uint8_t ch)
+OCP_INTERNAL int getchanalloc (struct itplayer *this, uint8_t ch)
 {
 	int num=0;
 	int i;
