@@ -57,61 +57,6 @@ static struct it_module mod;
 static struct it_instrument *insts;
 static struct it_sample *samps;
 
-static time_t starttime;      /* when did the song start, if paused, this is slided if unpaused */
-static time_t pausetime;      /* when did the pause start (fully paused) */
-static time_t pausefadestart; /* when did the pause fade start, used to make the slide */
-static int8_t pausefadedirection; /* 0 = no slide, +1 = sliding from pause to normal, -1 = sliding from normal to pause */
-
-static void togglepausefade (struct cpifaceSessionAPI_t *cpifaceSession)
-{
-	if (pausefadedirection)
-	{ /* we are already in a pause-fade, reset the fade-start point */
-		pausefadestart = clock_ms() - 1000 + (clock_ms() - pausefadestart);
-		pausefadedirection *= -1; /* inverse the direction */
-	} else if (cpifaceSession->InPause)
-	{ /* we are in full pause already */
-		pausefadestart = clock_ms();
-		starttime = starttime + pausefadestart - pausetime; /* we are unpausing, so push starttime the amount we have been paused */
-		cpifaceSession->mcpSet (cpifaceSession, -1, mcpMasterPause, cpifaceSession->InPause = 0);
-		pausefadedirection = 1;
-	} else { /* we were not in pause, start the pause fade */
-		pausefadestart = clock_ms();
-		pausefadedirection = -1;
-	}
-}
-
-static void dopausefade (struct cpifaceSessionAPI_t *cpifaceSession)
-{
-	int16_t i;
-	if (pausefadedirection > 0)
-	{ /* unpause fade */
-		i = ((int_fast32_t)(clock_ms() - pausefadestart)) * 64 / 1000;
-		if (i < 1)
-		{
-			i = 1;
-		}
-		if (i >= 64)
-		{
-			i = 64;
-			pausefadedirection = 0; /* we reached the end of the slide */
-		}
-	} else { /* pause fade */
-		i = 64 - ((int_fast32_t)(clock_ms() - pausefadestart)) * 64 / 1000;
-		if (i >= 64)
-		{
-			i = 64;
-		}
-		if (i <= 0)
-		{ /* we reached the end of the slide, finish the pause command */
-			pausefadedirection = 0;
-			pausetime = clock_ms();
-			cpifaceSession->mcpSet (cpifaceSession, -1, mcpMasterPause, cpifaceSession->InPause = 1);
-			return;
-		}
-	}
-	cpifaceSession->SetMasterPauseFadeParameters (cpifaceSession, i);
-}
-
 static int itpProcessKey(struct cpifaceSessionAPI_t *cpifaceSession, uint16_t key)
 {
 	int row;
@@ -132,30 +77,15 @@ static int itpProcessKey(struct cpifaceSessionAPI_t *cpifaceSession, uint16_t ke
 			cpifaceSession->KeyHelp (KEY_CTRL_HOME, "Jump to start of track");
 			return 0;
 		case 'p': case 'P':
-			togglepausefade (cpifaceSession);
+			cpifaceSession->TogglePauseFade (cpifaceSession);
 			break;
 		case KEY_CTRL_P:
-			/* cancel any pause-fade that might be in progress */
-			pausefadedirection = 0;
-			cpifaceSession->SetMasterPauseFadeParameters (cpifaceSession, 64);
-
-			if (cpifaceSession->InPause)
-			{
-				starttime = starttime + clock_ms() - pausetime; /* we are unpausing, so push starttime for the amount we have been paused */
-			} else {
-				pausetime = clock_ms();
-			}
-			cpifaceSession->mcpSet (cpifaceSession, -1, mcpMasterPause, cpifaceSession->InPause = !cpifaceSession->InPause);
+			cpifaceSession->TogglePause (cpifaceSession);
 			break;
 		case KEY_CTRL_HOME:
 			itpInstClear (cpifaceSession);
 			setpos (&itplayer, 0, 0);
-			if (cpifaceSession->InPause)
-			{
-				starttime = pausetime;
-			} else {
-				starttime = clock_ms();
-			}
+			cpifaceSession->ResetSongTimer (cpifaceSession);
 			break;
 		case '<':
 		case KEY_CTRL_LEFT:
@@ -189,10 +119,6 @@ static int itpProcessKey(struct cpifaceSessionAPI_t *cpifaceSession, uint16_t ke
 
 static int itpLooped (struct cpifaceSessionAPI_t *cpifaceSession, int LoopMod)
 {
-	if (pausefadedirection)
-	{
-		dopausefade(cpifaceSession);
-	}
 	setloop(&itplayer, LoopMod);
 	cpifaceSession->mcpDevAPI->Idle (cpifaceSession);
 
@@ -359,10 +285,8 @@ static int itpOpenFile (struct cpifaceSessionAPI_t *cpifaceSession, struct modul
 
 	cpifaceSession->GetPChanSample = cpifaceSession->mcpGetChanSample;
 
-	starttime = clock_ms();
 	cpifaceSession->InPause = 0;
 	cpifaceSession->mcpSet (cpifaceSession, -1, mcpMasterPause, 0);
-	pausefadedirection = 0;
 
 	return errOk;
 }
