@@ -37,12 +37,14 @@ extern "C"
 #include "filesel/filesystem.h"
 #include "stuff/err.h"
 #include "stuff/imsrtns.h"
+#include "oplconfig.h"
 }
 #include "oplplay.h"
 #include "oplptrak.h"
 #include "ocpemu.h"
 #include "oplKen.h"
 #include "oplNuked.h"
+#include "oplRetroWave.h"
 #include "oplSatoh.h"
 #include "oplWoody.h"
 
@@ -60,10 +62,6 @@ static struct oplStatusBuffer_t oplStatusBuffers[ROW_BUFFERS] = {{0}};
 struct oplStatus oplLastStatus; /* current register status */
 int oplLastPos;
 
-/* options */
-static int opl_inpause;
-//static int opl_looped;
-
 static unsigned long voll,volr;
 static int pan;
 static int srnd;
@@ -246,56 +244,50 @@ binistream *CProvider_Mem::open(std::string filename) const
 	{
 		retval = new binisstream(this->file_data, this->file_size);
 	} else {
-		uint32_t d = cpifaceSession->dirdb->FindAndRef (file->origin->parent->dirdb_ref, filename.c_str(), dirdb_use_children);
-
 		cpifaceSession->cpiDebug (cpifaceSession, "[Adplug OPL] Also need file \"%s\"\n", filename.c_str());
 
-		if (d != UINT32_MAX)
+		struct ocpfile_t *f = ocpdir_readdir_file (file->origin->parent, filename.c_str(), cpifaceSession->dirdb);
+		if (f)
 		{
-			struct ocpfile_t *f = file->origin->parent->readdir_file (file->origin->parent, d);
-			cpifaceSession->dirdb->Unref (d, dirdb_use_children);
-			if (f)
+			struct ocpfilehandle_t *file = f->open (f);
+			f->unref (f);
+
+			if (file)
 			{
-				struct ocpfilehandle_t *file = f->open (f);
-				f->unref (f);
+				size_t buffersize = 16*1024;
+				uint8_t *buffer = (uint8_t *)malloc (buffersize);
+				size_t bufferfill = 0;
 
-				if (file)
+				int res;
+				while (!file->eof(file))
 				{
-					size_t buffersize = 16*1024;
-					uint8_t *buffer = (uint8_t *)malloc (buffersize);
-					size_t bufferfill = 0;
-
-					int res;
-					while (!file->eof(file))
+					if (buffersize == bufferfill)
 					{
-						if (buffersize == bufferfill)
+						if (buffersize >= 16*1024*1024)
 						{
-							if (buffersize >= 16*1024*1024)
-							{
-								cpifaceSession->cpiDebug (cpifaceSession, "[Adplug OPL] \"%s\" is bigger than 16 Mb - further loading blocked\n", filename.c_str());
-								break;
-							}
-							buffersize += 16*1024;
-							buffer = (uint8_t *)realloc (buffer, buffersize);
-						}
-						res = file->read (file, buffer + bufferfill, buffersize - bufferfill);
-						if (res<=0)
+							cpifaceSession->cpiDebug (cpifaceSession, "[Adplug OPL] \"%s\" is bigger than 16 Mb - further loading blocked\n", filename.c_str());
 							break;
-						bufferfill += res;
+						}
+						buffersize += 16*1024;
+						buffer = (uint8_t *)realloc (buffer, buffersize);
 					}
-					if (bufferfill)
-					{
-						retval = new binisstreamfree(buffer, bufferfill);
-					} else {
-						free (buffer);
-					}
-					file->unref (file);
-				} else {
-					cpifaceSession->cpiDebug (cpifaceSession, "[Adplug OPL] Unable to open %s\n", filename.c_str());
+					res = file->read (file, buffer + bufferfill, buffersize - bufferfill);
+					if (res<=0)
+						break;
+					bufferfill += res;
 				}
+				if (bufferfill)
+				{
+					retval = new binisstreamfree(buffer, bufferfill);
+				} else {
+					free (buffer);
+				}
+				file->unref (file);
 			} else {
-				cpifaceSession->cpiDebug (cpifaceSession, "[Adplug OPL] Unable to find %s\n", filename.c_str());
+				cpifaceSession->cpiDebug (cpifaceSession, "[Adplug OPL] Unable to open %s\n", filename.c_str());
 			}
+		} else {
+			cpifaceSession->cpiDebug (cpifaceSession, "[Adplug OPL] Unable to find %s\n", filename.c_str());
 		}
 	}
 
@@ -341,21 +333,42 @@ OCP_INTERNAL int oplOpenPlayer (const char *filename /* needed for detection */,
 	str = cpifaceSession->configAPI->GetProfileString ("adplug", "emulator", "nuked");
 	if (!strcasecmp (str, "ken"))
 	{
-		opl = new Cocpemu(new oplKen(oplRate), oplRate);
+		opl = new Cocpemu(new oplKen(oplRate), oplRate, 0);
+	} else if (!strcasecmp (str, "retrowave"))
+	{
+		char *device = opl_config_retrowave_device (cpifaceSession->PipeProcess, cpifaceSession->configAPI);
+		if (!device)
+		{
+			cpifaceSession->cpiDebug (cpifaceSession, "[Adplug OPL] Failed to retrieve RetroWave device name\n");
+			cpifaceSession->plrDevAPI->Stop (cpifaceSession);
+			free (content);
+			return errFileMiss;
+		}
+		oplRetroWave *o = new oplRetroWave (cpifaceSession->cpiDebug, cpifaceSession, device, oplRate);
+		free (device);
+		if (o->FailedToOpen)
+		{
+			cpifaceSession->plrDevAPI->Stop (cpifaceSession);
+			delete(o);
+			free (content);
+			return errFileOpen;
+		}
+		opl = new Cocpemu(o, oplRate, 1);
 	} else if (!strcasecmp (str, "satoh"))
 	{
-		opl = new Cocpemu(new oplSatoh(oplRate), oplRate);
+		opl = new Cocpemu(new oplSatoh(oplRate), oplRate, 0);
 	} else if (!strcasecmp (str, "woody"))
 	{
-		opl = new Cocpemu(new oplWoody(oplRate), oplRate);
+		opl = new Cocpemu(new oplWoody(oplRate), oplRate, 0);
 	} else /* nuked */
 	{
-		opl = new Cocpemu(new oplNuked(oplRate), oplRate);
+		opl = new Cocpemu(new oplNuked(oplRate), oplRate, 0);
 	}
 
 	CProvider_Mem prMem (filename, file, cpifaceSession, content, len);
 	if (!(p = CAdPlug::factory(filename, opl, CAdPlug::players, prMem)))
 	{
+		cpifaceSession->plrDevAPI->Stop (cpifaceSession);
 		delete (opl);
 		cpifaceSession->cpiDebug (cpifaceSession, "[Adplug OPL] Failed to load file\n");
 		return errFormStruc;
@@ -376,8 +389,6 @@ OCP_INTERNAL int oplOpenPlayer (const char *filename /* needed for detection */,
 	cpifaceSession->mcpGet = oplGet;
 	cpifaceSession->Normalize (cpifaceSession, mcpNormalizeDefaultPlayP);
 
-	opl_inpause = 0;
-
 	active=1;
 
 	oplTrkSetup (cpifaceSession, p);
@@ -407,11 +418,6 @@ OCP_INTERNAL int oplIsLooped (void)
 	return 0; // opl_looped == 3;
 }
 
-OCP_INTERNAL void oplPause (uint8_t p)
-{
-	opl_inpause=p;
-}
-
 static void oplSetSpeed(uint16_t sp)
 {
 	if (sp < 4)
@@ -468,7 +474,7 @@ static void oplIdler (struct cpifaceSessionAPI_t *cpifaceSession)
 		{
 			length1=opltowrite;
 		}
-		opl->update(oplbuf+(pos1<<1) /* stereo */, length1); /* given in samples */
+		opl->update(oplbuf+(pos1<<1) /* stereo */, length1, oplbufrate); /* given in samples */
 
 		opltowrite-=length1;
 
@@ -500,7 +506,7 @@ OCP_INTERNAL void oplIdle (struct cpifaceSessionAPI_t *cpifaceSession)
 		return;
 	}
 
-	if (opl_inpause /*|| (opl_looped == 3)*/)
+	if (cpifaceSession->InPause /*|| (opl_looped == 3)*/)
 	{
 		cpifaceSession->plrDevAPI->Pause (1);
 	} else {
@@ -658,6 +664,12 @@ OCP_INTERNAL void oplIdle (struct cpifaceSessionAPI_t *cpifaceSession)
 						length1-=progress;
 						targetlength--;
 
+						if (length1 < 0)
+						{
+							length2 += length1;
+							length1 = 0;
+						}
+
 						accumulated_target++;
 					} /* while (targetlength && length1) */
 					length1 = length2;
