@@ -83,29 +83,28 @@ static class CAdPlugDatabase *adplugdb_ocp;
 OCP_INTERNAL int opl_type_init (PluginInitAPI_t *API)
 {
 	char *path=0;
-	const char *home = getenv ("HOME");
 
 	adplugdb_ocp = new CAdPlugDatabase();
 	if (adplugdb_ocp)
 	{
-		API->makepath_malloc (&path, 0, API->configAPI->DataDir, "adplug.db", 0);
+		path = (char *)malloc (strlen (API->configAPI->DataPath) + strlen ("adplug.db") + 1);
 		if (path)
 		{
+			sprintf (path, "%sadplug.db", API->configAPI->DataPath);
 			adplugdb_ocp->load(path);
 			free (path); path=0;
 		}
 		adplugdb_ocp->load("/usr/com/adplug/adplug.db");
 		adplugdb_ocp->load("/usr/share/adplug/adplug.db");
-		if (home && home[0])
+
+		path = (char *)malloc (strlen (API->configAPI->HomePath) + strlen (".adplug/adplug.db") + 1);
+		if (path)
 		{
-			path = (char *)malloc (strlen(home) + 19);
-			if (path)
-			{
-				sprintf (path, "%s%s.adplug/adplug.db", home, home[strlen(home)]-1=='/'?"":"/");
-				adplugdb_ocp->load(path);
-				free (path); path=0;
-			}
+			sprintf (path, "%s.adplug/adplug.db", API->configAPI->HomePath);
+			adplugdb_ocp->load(path);
+			free (path); path=0;
 		}
+
 		CAdPlug::set_database (adplugdb_ocp);
 	}
 
@@ -141,6 +140,7 @@ OCP_INTERNAL void opl_type_done (PluginCloseAPI_t *API)
 	if (adplugdb_ocp)
 	{
 		CAdPlug::set_database (0);
+		adplugdb_ocp->wipe();
 		delete (adplugdb_ocp);
 		adplugdb_ocp = 0;
 	}
